@@ -158,7 +158,7 @@ int Model_TW::pdf(double *RsumlogPDF, double *RPDFlow, double *RPDFupp, double *
   double gg = contamination_strength(phi);
   double g_prob = 0.0;
   double weight = 0.0;
-  int N_cut = N_dt;
+  int N_cut = N_dt-1;
 
   /* set value of first element for first passage time array */
   p_fpt[0][0] = tnd;
@@ -541,7 +541,7 @@ int Model_TW::cdf(double *RsumlogCDF, double *RCDFlow, double *RCDFupp, double *
   double gg = contamination_strength(phi);
   double g_prob = 0.0;
   double weight = 0.0;
-  int N_cut = N_dt;
+  int N_cut = N_dt-1;
 
   /* set value of first element for first passage time array */
   p_fpt[0][0] = tnd;
